@@ -1,11 +1,9 @@
-from collections import defaultdict
-
 from ilexconf.helpers import keyval_to_dict
 
 from typing import Any, Dict, Mapping, List, Sequence
 
 
-class Config(defaultdict):
+class Config(dict):
     """
     Config is a dictionary of other configs forming hierarchical structure.
     """
@@ -15,10 +13,7 @@ class Config(defaultdict):
         Constructor.
         """
 
-        # Initialize super class as defaultdict with None value for
-        # nonexisting keys, so that None is returned instead of throwing
-        # KeyError exection.
-        super().__init__(*(lambda: Config(),))
+        super().__init__()
 
         # Merge in values of mappings
         self.merge(*mappings, **kwargs)
@@ -26,36 +21,33 @@ class Config(defaultdict):
     def __getitem__(self, item):
         if isinstance(item, str) and "." in item:
             key, subkey = item.split(".", maxsplit=1)
-            return dict.__getitem__(self, key).__getitem__(subkey)
+            return self._dd_getitem(key).__getitem__(subkey)
         else:
-            return dict.__getitem__(self, item)
+            return self._dd_getitem(item)
 
     def __getattr__(self, attr):
-        return dict.__getitem__(self, attr)
+        return self._dd_getitem(attr)
 
     def __setitem__(self, item, value):
+        value = self._parse(value)
         if isinstance(item, str) and "." in item:
             key, subkey = item.split(".", maxsplit=1)
-            dict.__getitem__(self, key).__setitem__(subkey, value)
+            self._dd_getitem(key).__setitem__(subkey, value)
         else:
             dict.__setitem__(self, item, value)
 
     def __setattr__(self, attr, value):
+        value = self._parse(value)
         dict.__setitem__(self, attr, value)
 
     def __repr__(self):
-        # d = dict()
-        # for key in self.keys():
-        #     if isinstance(self[key], Config):
-        #         d[key] = self[key].__repr__()
-        #     else:
-        #         d[key] = str(self[key])
         return f"Config{dict.__repr__(self)}"
 
     def merge(self, *mappings: Mapping[Any, Any], **kwargs) -> None:
         """
         Merge values of mappings with current config recursively.
         """
+
         # For every key of that mapping
         for mapping in mappings:
             for key, value in mapping.items():
@@ -76,30 +68,9 @@ class Config(defaultdict):
             keyval_dict = keyval_to_dict(k, v)
             self.merge(keyval_dict)
 
-    def _parse(self, value: Any):
-        # If value is another Mapping: dict, Config, etc.
-        if isinstance(value, Mapping):
-            return Config(value)
-
-        # If value is a Sequence but not str, bytes, or bytearray
-        elif isinstance(value, Sequence) and not isinstance(
-            value, (str, bytes, bytearray)
-        ):
-            l = list()
-            for i in value:
-                l.append(self._parse(i))
-            # Return sequence with the same type
-            t = type(value)
-            return t(l)
-
-        # If value is anything else
-        else:
-            return value
-
     def flatten(self, prefix="", separator="."):
-        """
-        Flatten Config object to dictionary with depth 1.
-        """
+        """Flatten current config so that there is no hierarchy."""
+
         d = dict()
         p = f"{prefix}{separator}" if prefix else ""
         for key in self.keys():
@@ -108,31 +79,56 @@ class Config(defaultdict):
                 d.update(flattened)
             else:
                 d[f"{p}{key}"] = self[key]
-        return d
+        return Config(d)
+
+    def lower(self):
+        """Lowercase all string keys of the configuration"""
+
+        return Config(self.as_dict(lowercase=True))
+
+    def upper(self):
+        """Uppercase all string keys of the configuration"""
+
+        return Config(self.as_dict(uppercase=True))
 
     def copy(self):
-        """
-        Return deep copy of the Config object.
-        """
+        """Return deep copy of the Config object."""
+
         return Config(self.as_dict())
 
-    def as_dict(self):
+    def as_dict(self, lowercase: bool = False, uppercase: bool = False):
+        """Convert configuration to dict object.
+
+        `lowercase` takes precedence over `uppercase`.
+        """
+
         d = dict()
         for key in self.keys():
+            assignment_key = (
+                key.lower()
+                if lowercase and isinstance(key, str)
+                else key.upper()
+                if uppercase and isinstance(key, str)
+                else key
+            )
             if isinstance(self[key], Config):
-                d[key] = self[key].as_dict()
+                d[assignment_key] = self[key].as_dict(
+                    lowercase=lowercase, uppercase=uppercase
+                )
             else:
-                d[key] = self[key]
+                d[assignment_key] = self[key]
         return d
 
     def as_table(
         self,
-        headers: List[str] = ["Setting", "Value"],
+        headers: List[str] = ["Key", "Value"],
         indentation: str = "  ",
         limit: int = 0,
     ):
-        """
-        Transform multilevel dictionary into table structure suitable for printing by Cleo library.
+        """Transform configuration into table structure.
+
+        Returns tuple of headers and rows.
+        Returned structure is suitable for printing by Cleo library.
         """
 
         def processor(c: Dict, rows: List, level: int):
@@ -178,3 +174,32 @@ class Config(defaultdict):
             rows.append(["...", "..."])
 
         return (headers, rows)
+
+    def _parse(self, value: Any):
+        # If value is another Mapping: dict, Config, etc.
+        if isinstance(value, Mapping):
+            return Config(value)
+
+        # If value is a Sequence but not str, bytes, or bytearray
+        elif isinstance(value, Sequence) and not isinstance(
+            value, (str, bytes, bytearray)
+        ):
+            l = list()
+            for i in value:
+                l.append(self._parse(i))
+            # Return sequence with the same type
+            t = type(value)
+            return t(l)
+
+        # If value is anything else
+        else:
+            return value
+
+    def _dd_getitem(self, item):
+        """Implements defaultdict feature
+
+        DefaultDict getitem method
+        """
+        if item not in self:
+            dict.__setitem__(self, item, Config())
+        return dict.__getitem__(self, item)
